## Synopsis

`VINCA` is a command-line spaced-repetition study tool.

## Installing Vinca

`pip install vinca`

## Basic commands

|command           |   description                            |  
|------------------|------------------------------------------|  
|--help            |   full screen help                       |  
|basic             |   create question and answer cards       |  
|review            |   study your cards                       |  
|browse            |   interactively manage your cards        |  
|count             |   simple summary statistics              |  
|tutorial review   |   study a tutorial deck of twenty cards  |  

## Screenshots

![vinca stats](./utils/stats.png)
*`vinca stats`*

![test](./utils/screencast.gif?)
*test*
